import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import ExpansionPanel from "@material-ui/core/ExpansionPanel";
import ExpansionPanelSummary from "@material-ui/core/ExpansionPanelSummary";
import ExpansionPanelDetails from "@material-ui/core/ExpansionPanelDetails";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import PropTypes from "prop-types";
import Spinner from "../../../components/common/Spinner";
import { useTranslation } from "react-i18next";
import ReleaseNotesSummary from "./ReleaseNotesSummary";
import styles from "../../../components/common/styles/divStyles";

const useStyles = makeStyles(styles);

const ReleaseNotesListComponent = ({ releaseNotes }) => {
  const classes = useStyles();
  const { t } = useTranslation();

  return (
    <div className={classes.root}>
      <h2>{t("ReleaseNotes.Title")}</h2>
      {releaseNotes.loading ? (
        <Spinner />
      ) : (
        releaseNotes.loaded &&
        releaseNotes.map((note) => {
          return (
            <ExpansionPanel key={note.version}>
              <ExpansionPanelSummary
                expandIcon={<ExpandMoreIcon />}
                id={`panel-${note.version}-header`}
              >
                <ReleaseNotesSummary releaseNote={note} />
              </ExpansionPanelSummary>
              <ExpansionPanelDetails>
                <div>TO DO</div>
              </ExpansionPanelDetails>
            </ExpansionPanel>
          );
        })
      )}
    </div>
  );
};

ReleaseNotesListComponent.propTypes = {
  releaseNotes: PropTypes.array.isRequired
};

export default ReleaseNotesListComponent;
